import * as i0 from '@angular/core';
import { InjectionToken, Directive, Optional, Inject, Input, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';

const HIGHLIGHTJS_CONFIG = new InjectionToken('HighlightJs-Config');

class HighlightJsDirective {
    constructor(el, ngModel, doc, cog, ngZone) {
        this.el = el;
        this.ngModel = ngModel;
        this.doc = doc;
        this.ngZone = ngZone;
        this.lang = 'html';
        this.mode = 'simple';
        Object.assign(this, cog);
    }
    escapeHTML(str) {
        return (str || '').replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;').replace(/'/g, '&apos;');
    }
    init() {
        this.ngZone.runOutsideAngular(() => {
            this.destroy();
            const el = this.el.nativeElement;
            const code = this.code || '' + el.innerHTML.trim();
            const doc = this.doc;
            this.codeEl = doc.createElement(this.mode === 'default' ? 'div' : 'pre');
            if (this.codeEl == null)
                return;
            const isSimple = this.mode === 'simple';
            if (isSimple) {
                if (this.lang) {
                    this.codeEl.className = this.lang;
                }
                this.parentEl = el.parentNode;
                this.parentEl.insertBefore(this.codeEl, el.nextSibling);
            }
            else {
                this.parentEl = el;
                this.parentEl.innerHTML = ``;
                this.parentEl.appendChild(this.codeEl);
            }
            this.codeEl.innerHTML = code;
            const hljs = doc.defaultView.hljs;
            if (hljs == null) {
                if (typeof ngDevMode === 'undefined' || ngDevMode) {
                    console.warn(`Can't find hljs under window`);
                }
                return;
            }
            hljs.configure({ ...this.options });
            if (isSimple) {
                hljs.highlightElement(this.codeEl);
            }
            else {
                this.codeEl.querySelectorAll('pre code').forEach((block) => {
                    hljs.highlightElement(block);
                });
            }
        });
    }
    destroy() {
        if (this.codeEl && this.parentEl) {
            this.parentEl.removeChild(this.codeEl);
            this.codeEl = undefined;
        }
    }
    ngAfterViewInit() {
        this.init();
        if (this.ngModel) {
            this.modelValue$ = this.ngModel.valueChanges?.subscribe((res) => {
                this.code = this.escapeHTML(res);
                this.init();
            });
        }
        else {
            this.initMutation();
        }
    }
    ngOnDestroy() {
        this.destroy();
        this.destroyMutation();
        if (this.modelValue$) {
            this.modelValue$.unsubscribe();
        }
    }
    initMutation() {
        if (typeof MutationObserver === 'undefined') {
            return;
        }
        this.ngZone.runOutsideAngular(() => {
            this.observer = new MutationObserver(this.init.bind(this));
            this.observer.observe(this.el.nativeElement, {
                characterData: true,
                childList: true,
                subtree: true,
            });
        });
    }
    destroyMutation() {
        this.observer?.disconnect();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsDirective, deps: [{ token: i0.ElementRef }, { token: i1.NgModel, optional: true }, { token: DOCUMENT }, { token: HIGHLIGHTJS_CONFIG, optional: true }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.1.6", type: HighlightJsDirective, isStandalone: true, selector: "[highlight-js]", inputs: { options: "options", lang: "lang", code: "code", mode: "mode" }, host: { properties: { "style.display": "mode === 'simple' ? 'none' : null" } }, exportAs: ["highlightJs"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[highlight-js]',
                    host: {
                        '[style.display]': `mode === 'simple' ? 'none' : null`,
                    },
                    exportAs: 'highlightJs',
                    standalone: true,
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1.NgModel, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [HIGHLIGHTJS_CONFIG]
                }] }, { type: i0.NgZone }]; }, propDecorators: { options: [{
                type: Input
            }], lang: [{
                type: Input
            }], code: [{
                type: Input
            }], mode: [{
                type: Input
            }] } });

const DIRECTIVES = [HighlightJsDirective];
class HighlightJsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsModule, imports: [FormsModule, HighlightJsDirective], exports: [HighlightJsDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsModule, imports: [FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.6", ngImport: i0, type: HighlightJsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FormsModule, ...DIRECTIVES],
                    exports: DIRECTIVES,
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { HIGHLIGHTJS_CONFIG, HighlightJsDirective, HighlightJsModule };
//# sourceMappingURL=ngx-highlight-js.mjs.map
